@@ -7,7 +7,7 @@
 
  This code is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2, or (at your option)
+ the Free Software Foundation; either version 3, or (at your option)
  any later version.
 
  This code is distributed in the hope that it will be useful,
@@ -24,27 +24,22 @@
 
 /////////////////////////////////////////////////////////////////////
 
-#ifndef AGENT2D_BHV_BASIC_MOVE_H
-#define AGENT2D_BHV_BASIC_MOVE_H
+#ifndef BHV_BASIC_MOVE_H
+#define BHV_BASIC_MOVE_H
 
 #include <rcsc/geom/vector_2d.h>
 #include <rcsc/player/soccer_action.h>
 
 class Bhv_BasicMove
     : public rcsc::SoccerBehavior {
-private:
-    const rcsc::Vector2D M_home_pos;
-
 public:
-    Bhv_BasicMove( const rcsc::Vector2D & home_pos )
-        : M_home_pos( home_pos )
+    Bhv_BasicMove()
       { }
 
     bool execute( rcsc::PlayerAgent * agent );
 
 private:
-    double getDashPower( const rcsc::PlayerAgent * agent,
-                         const rcsc::Vector2D & target_point );
+    double getDashPower( const rcsc::PlayerAgent * agent );
 };
 
 #endif
