@@ -445,7 +445,7 @@ Bhv_SetPlay::is_kicker( const PlayerAgent * agent )
     double second_min_dist2 = std::numeric_limits< double >::max();
     for ( int unum = 1; unum <= 11; ++unum )
     {
-        if ( unum == wm.teammateGoalieUnum() ) continue;
+        if ( unum == wm.ourGoalieUnum() ) continue;
 
         Vector2D home_pos = Strategy::i().getPosition( unum );
         if ( ! home_pos.isValid() ) continue;
@@ -473,12 +473,12 @@ Bhv_SetPlay::is_kicker( const PlayerAgent * agent )
 
     if ( kicker_unum != 0 )
     {
-        kicker = wm.teammate( kicker_unum );
+        kicker = wm.ourPlayer( kicker_unum );
     }
 
     if ( second_kicker_unum != 0 )
     {
-        second_kicker = wm.teammate( second_kicker_unum );
+        second_kicker = wm.ourPlayer( second_kicker_unum );
     }
 
     if ( ! kicker )
