@@ -24,32 +24,29 @@
 
 /////////////////////////////////////////////////////////////////////
 
-#ifndef TOKYOTECH_BHV_SET_PLAY_INDIRECT_FREE_KICK_H
-#define TOKYOTECH_BHV_SET_PLAY_INDIRECT_FREE_KICK_H
+#ifndef BHV_SET_PLAY_INDIRECT_FREE_KICK_H
+#define BHV_SET_PLAY_INDIRECT_FREE_KICK_H
 
 #include <rcsc/geom/vector_2d.h>
 #include <rcsc/player/soccer_action.h>
 
 class Bhv_SetPlayIndirectFreeKick
     : public rcsc::SoccerBehavior {
-private:
-    static bool S_kicker_canceled;
-    const rcsc::Vector2D M_home_pos;
-
 public:
-    Bhv_SetPlayIndirectFreeKick( const rcsc::Vector2D & home_pos )
-        : M_home_pos( home_pos )
+
+    Bhv_SetPlayIndirectFreeKick()
       { }
 
     bool execute( rcsc::PlayerAgent * agent );
 
 private:
 
-    bool isKicker( const rcsc::PlayerAgent * agent );
-    void doKick( rcsc::PlayerAgent * agent );
-    void doMove( rcsc::PlayerAgent * agent );
+    void doKicker( rcsc::PlayerAgent * agent );
+    bool doKickWait( rcsc::PlayerAgent * agent );
+    bool doKickToShooter( rcsc::PlayerAgent * agent );
 
-    rcsc::Vector2D getMovePoint( const rcsc::PlayerAgent * agent );
+    void doOffenseMove( rcsc::PlayerAgent * agent );
+    void doDefenseMove( rcsc::PlayerAgent * agent );
 };
 
 #endif
