@@ -7,7 +7,7 @@
 
  This code is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2, or (at your option)
+ the Free Software Foundation; either version 3, or (at your option)
  any later version.
 
  This code is distributed in the hope that it will be useful,
@@ -24,29 +24,26 @@
 
 /////////////////////////////////////////////////////////////////////
 
-#ifndef AGENT2D_BHV_SET_PLAY_KICK_IN_H
-#define AGENT2D_BHV_SET_PLAY_KICK_IN_H
+#ifndef BHV_SET_PLAY_KICK_IN_H
+#define BHV_SET_PLAY_KICK_IN_H
 
 #include <rcsc/geom/vector_2d.h>
 #include <rcsc/player/soccer_action.h>
 
-// our kick in
-
 class Bhv_SetPlayKickIn
     : public rcsc::SoccerBehavior {
-private:
-    const rcsc::Vector2D M_home_pos;
 public:
-    Bhv_SetPlayKickIn( const rcsc::Vector2D & home_pos )
-        : M_home_pos( home_pos )
+
+    Bhv_SetPlayKickIn()
       { }
 
     bool execute( rcsc::PlayerAgent * agent );
 
 private:
-    bool isKicker( const rcsc::PlayerAgent * agent );
 
     void doKick( rcsc::PlayerAgent * agent );
+    bool doKickWait( rcsc::PlayerAgent * agent );
+
     void doMove( rcsc::PlayerAgent * agent );
 };
 
