@@ -131,7 +131,7 @@ IntentionPassKickFindReceiver::finished( const PlayerAgent * agent )
     // check receiver
     //
 
-    const AbstractPlayerObject * receiver = wm.teammate( M_receiver_unum );
+    const AbstractPlayerObject * receiver = wm.ourPlayer( M_receiver_unum );
 
     if ( ! receiver )
     {
@@ -214,7 +214,7 @@ bool
 IntentionPassKickFindReceiver::execute( PlayerAgent * agent )
 {
     const WorldModel & wm = agent->world();
-    const AbstractPlayerObject * receiver = wm.teammate( M_receiver_unum );
+    const AbstractPlayerObject * receiver = wm.ourPlayer( M_receiver_unum );
 
     if ( ! receiver )
     {
@@ -222,7 +222,7 @@ IntentionPassKickFindReceiver::execute( PlayerAgent * agent )
     }
 
     const Vector2D next_self_pos = agent->effector().queuedNextMyPos();
-    const AngleDeg next_self_body = agent->effector().queuedNextMyBody();
+    //const AngleDeg next_self_body = agent->effector().queuedNextMyBody();
     const double next_view_width = agent->effector().queuedNextViewWidth().width() * 0.5;
 
     const Vector2D receiver_pos = receiver->pos() + receiver->vel();
@@ -297,7 +297,7 @@ Bhv_PassKickFindReceiver::execute( PlayerAgent * agent )
         return false;
     }
 
-    const AbstractPlayerObject * receiver = wm.teammate( pass.targetPlayerUnum() );
+    const AbstractPlayerObject * receiver = wm.ourPlayer( pass.targetPlayerUnum() );
 
     if ( ! receiver )
     {
@@ -472,7 +472,7 @@ Bhv_PassKickFindReceiver::doCheckReceiver( PlayerAgent * agent,
         return false;
     }
 
-    const AbstractPlayerObject * receiver = wm.teammate( pass.targetPlayerUnum() );
+    const AbstractPlayerObject * receiver = wm.ourPlayer( pass.targetPlayerUnum() );
 
     if ( ! receiver )
     {
@@ -695,7 +695,6 @@ Bhv_PassKickFindReceiver::getKeepBallVel( const rcsc::WorldModel & wm )
     // create keep target point
     //
 
-    int best_angle = -1;
     Vector2D best_ball_vel = Vector2D::INVALIDATED;
     int best_opponent_step = 0;
     double best_ball_speed = 1000.0;
@@ -795,7 +794,6 @@ Bhv_PassKickFindReceiver::getKeepBallVel( const rcsc::WorldModel & wm )
 #endif
         if ( min_step > best_opponent_step )
         {
-            best_angle = a;
             best_ball_vel = ball_vel;
             best_opponent_step = min_step;
             best_ball_speed = ball_speed;
@@ -804,7 +802,6 @@ Bhv_PassKickFindReceiver::getKeepBallVel( const rcsc::WorldModel & wm )
         {
             if ( best_ball_speed > ball_speed )
             {
-                best_angle = a;
                 best_ball_vel = ball_vel;
                 best_opponent_step = min_step;
                 best_ball_speed = ball_speed;
@@ -827,7 +824,7 @@ Bhv_PassKickFindReceiver::doTurnBodyNeckToReceiver( PlayerAgent * agent,
     const ServerParam & SP = ServerParam::i();
     const WorldModel & wm = agent->world();
 
-    const AbstractPlayerObject * receiver = wm.teammate( pass.targetPlayerUnum() );
+    const AbstractPlayerObject * receiver = wm.ourPlayer( pass.targetPlayerUnum() );
 
     const double next_view_half_width = agent->effector().queuedNextViewWidth().width() * 0.5;
     const double view_min = SP.minNeckAngle() - next_view_half_width + 10.0;
@@ -974,7 +971,7 @@ Bhv_PassKickFindReceiver::doSayPass( PlayerAgent * agent,
          && ! agent->effector().queuedNextBallKickable()
          )
     {
-        const AbstractPlayerObject * receiver = agent->world().teammate( receiver_unum );
+        const AbstractPlayerObject * receiver = agent->world().ourPlayer( receiver_unum );
         if ( ! receiver )
         {
             return;
