@@ -378,11 +378,10 @@ ClearGenerator::predictOpponentsReachStep( const WorldModel & wm,
     int min_step = 50;
     int out_of_pitch_step = -1;
 
-    //const AbstractPlayerCont::const_iterator o_end = opponents.end();
-    //for ( AbstractPlayerCont::const_iterator o = opponents.begin();
-    const AbstractPlayerCont::const_iterator o_end = wm.allOpponents().end();
-    for ( AbstractPlayerCont::const_iterator o = wm.allOpponents().begin();
-          o != o_end;
+    for ( AbstractPlayerCont::const_iterator
+              o = wm.theirPlayers().begin(),
+              end = wm.theirPlayers().end();
+          o != end;
           ++o )
     {
         int step = predictOpponentReachStep( *o,
