@@ -33,6 +33,10 @@ class SimplePassChecker
     : public PassChecker {
 
 public:
+
+    SimplePassChecker()
+      { }
+
     bool operator()( const PredictState & state,
                      const rcsc::AbstractPlayerObject & from,
                      const rcsc::AbstractPlayerObject & to,
