@@ -633,8 +633,9 @@ TackleGenerator::predictOpponentsReachStep( const WorldModel & wm,
 #endif
 
     int min_step = first_min_step;
-    const AbstractPlayerCont::const_iterator end = wm.allOpponents().end();
-    for ( AbstractPlayerCont::const_iterator o = wm.allOpponents().begin();
+    for ( AbstractPlayerCont::const_iterator
+              o = wm.theirPlayers().begin(),
+              end = wm.theirPlayers().end();
           o != end;
           ++o )
     {
