@@ -30,20 +30,16 @@
 
 #include "role_defensive_half.h"
 
-#include "strategy.h"
-
+#include "bhv_chain_action.h"
 #include "bhv_basic_offensive_kick.h"
 #include "bhv_basic_move.h"
 
-#include <rcsc/formation/formation.h>
-
 #include <rcsc/player/player_agent.h>
-#include <rcsc/player/intercept_table.h>
 #include <rcsc/player/debug_client.h>
 
 #include <rcsc/common/logger.h>
-#include <rcsc/common/server_param.h>
 
+using namespace rcsc;
 
 const std::string RoleDefensiveHalf::NAME( "DefensiveHalf" );
 
@@ -59,9 +55,9 @@ rcss::RegHolder role = SoccerRole::creators().autoReg( &RoleDefensiveHalf::creat
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
-void
-RoleDefensiveHalf::execute( rcsc::PlayerAgent * agent )
+ */
+bool
+RoleDefensiveHalf::execute( PlayerAgent * agent )
 {
     bool kickable = agent->world().self().isKickable();
     if ( agent->world().existKickableTeammate()
@@ -80,53 +76,33 @@ RoleDefensiveHalf::execute( rcsc::PlayerAgent * agent )
         doMove( agent );
     }
 
+    return true;
 }
 
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
+ */
 void
-RoleDefensiveHalf::doKick( rcsc::PlayerAgent * agent )
+RoleDefensiveHalf::doKick( PlayerAgent * agent )
 {
-    switch ( Strategy::get_ball_area( agent->world().ball().pos() ) ) {
-    case Strategy::BA_CrossBlock:
-    case Strategy::BA_Stopper:
-    case Strategy::BA_Danger:
-    case Strategy::BA_DribbleBlock:
-    case Strategy::BA_DefMidField:
-    case Strategy::BA_DribbleAttack:
-    case Strategy::BA_OffMidField:
-    case Strategy::BA_Cross:
-    case Strategy::BA_ShootChance:
-    default:
-        Bhv_BasicOffensiveKick().execute( agent );
-        break;
+    if ( Bhv_ChainAction().execute( agent ) )
+    {
+        dlog.addText( Logger::TEAM,
+                      __FILE__": (execute) do chain action" );
+        agent->debugClient().addMessage( "ChainAction" );
+        return;
     }
+
+    Bhv_BasicOffensiveKick().execute( agent );
 }
 
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
+ */
 void
-RoleDefensiveHalf::doMove( rcsc::PlayerAgent * agent )
+RoleDefensiveHalf::doMove( PlayerAgent * agent )
 {
-    rcsc::Vector2D home_pos = Strategy::i().getPosition( agent->world().self().unum() );
-    if ( ! home_pos.valid() ) home_pos.assign( 0.0, 0.0 );
-
-    switch ( Strategy::get_ball_area( agent->world() ) ) {
-    case Strategy::BA_CrossBlock:
-    case Strategy::BA_Stopper:
-    case Strategy::BA_Danger:
-    case Strategy::BA_DribbleBlock:
-    case Strategy::BA_DefMidField:
-    case Strategy::BA_DribbleAttack:
-    case Strategy::BA_OffMidField:
-    case Strategy::BA_Cross:
-    case Strategy::BA_ShootChance:
-    default:
-        Bhv_BasicMove( home_pos ).execute( agent );
-        break;
-    }
+    Bhv_BasicMove().execute( agent );
 }
