@@ -7,7 +7,7 @@
 
  This code is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2, or (at your option)
+ the Free Software Foundation; either version 3, or (at your option)
  any later version.
 
  This code is distributed in the hope that it will be useful,
@@ -24,8 +24,8 @@
 
 /////////////////////////////////////////////////////////////////////
 
-#ifndef AGENT2D_ROLE_SIDE_BACK_H
-#define AGENT2D_ROLE_SIDE_BACK_H
+#ifndef ROLE_SIDE_BACK_H
+#define ROLE_SIDE_BACK_H
 
 #include "soccer_role.h"
 
@@ -44,7 +44,7 @@ public:
       { }
 
     virtual
-    void execute( rcsc::PlayerAgent * agent );
+    bool execute( rcsc::PlayerAgent * agent );
 
 
     static
@@ -64,6 +64,7 @@ private:
 
     void doKick( rcsc::PlayerAgent * agent );
     void doMove( rcsc::PlayerAgent * agent );
+
 };
 
 
