@@ -7,7 +7,7 @@
 
  This code is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2, or (at your option)
+ the Free Software Foundation; either version 3, or (at your option)
  any later version.
 
  This code is distributed in the hope that it will be useful,
@@ -24,8 +24,8 @@
 
 /////////////////////////////////////////////////////////////////////
 
-#ifndef AGENT2D_ROLE_SIDE_FORWARD_H
-#define AGENT2D_ROLE_SIDE_FORWARD_H
+#ifndef ROLE_SIDE_FORWARD_H
+#define ROLE_SIDE_FORWARD_H
 
 #include "soccer_role.h"
 
@@ -35,32 +35,33 @@ private:
 
 public:
 
-    explicit
-    RoleSideForward( boost::shared_ptr< const rcsc::Formation > f )
-        : SoccerRole( f )
+    static const std::string NAME;
+
+    RoleSideForward()
       { }
 
     ~RoleSideForward()
       { }
 
     virtual
-    void execute( rcsc::PlayerAgent * agent );
+    bool execute( rcsc::PlayerAgent * agent );
 
     static
-    std::string name()
+    const
+    std::string & name()
       {
-          return std::string( "SideForward" );
+          return NAME;
       }
 
     static
-    SoccerRole * create( boost::shared_ptr< const rcsc::Formation > f )
+    SoccerRole::Ptr create()
       {
-          return ( new RoleSideForward( f ) );
+          SoccerRole::Ptr ptr( new RoleSideForward() );
+          return ptr;
       }
 private:
 
     void doKick( rcsc::PlayerAgent * agent );
-
     void doMove( rcsc::PlayerAgent * agent );
 };
 
