@@ -282,8 +282,8 @@ SampleCommunication::updateCurrentSender( const PlayerAgent * agent )
         //
         // exclude goalie
         //
-        const int goalie_unum = ( wm.teammateGoalieUnum() != Unum_Unknown
-                                  ? wm.teammateGoalieUnum()
+        const int goalie_unum = ( wm.ourGoalieUnum() != Unum_Unknown
+                                  ? wm.ourGoalieUnum()
                                   : Strategy::i().goalieUnum() );
 
         for ( int unum = 1; unum <= 11; ++unum )
@@ -654,10 +654,10 @@ SampleCommunication::sayBallAndPlayers( PlayerAgent * agent )
     //
     // opponent goalie
     //
-    if ( 1 <= wm.opponentGoalieUnum()
-         && wm.opponentGoalieUnum() <= 11 )
+    if ( 1 <= wm.theirGoalieUnum()
+         && wm.theirGoalieUnum() <= 11 )
     {
-        int num = wm.opponentGoalieUnum() + 11;
+        int num = wm.theirGoalieUnum() + 11;
         double diff = wm.time().cycle() - am.goalieTime().cycle();
         objects[num].score_ = std::min( objects[num].score_, diff );
     }
@@ -739,7 +739,7 @@ SampleCommunication::sayBallAndPlayers( PlayerAgent * agent )
         for ( int unum = 1; unum <= 11; ++unum )
         {
             {
-                const AbstractPlayerObject * t = wm.teammate( unum );
+                const AbstractPlayerObject * t = wm.ourPlayer( unum );
                 if ( ! t
                      || t->unumCount() >= 2 )
                 {
@@ -754,7 +754,7 @@ SampleCommunication::sayBallAndPlayers( PlayerAgent * agent )
                 }
             }
             {
-                const AbstractPlayerObject * o = wm.opponent( unum );
+                const AbstractPlayerObject * o = wm.theirPlayer( unum );
                 if ( ! o
                      || o->unumCount() >= 2 )
                 {
