@@ -7,7 +7,7 @@
 
  This code is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2, or (at your option)
+ the Free Software Foundation; either version 3, or (at your option)
  any later version.
 
  This code is distributed in the hope that it will be useful,
@@ -24,13 +24,25 @@
 
 /////////////////////////////////////////////////////////////////////
 
-#ifndef AGENT2D_SAMPLE_PLAYER_H
-#define AGENT2D_SAMPLE_PLAYER_H
+#ifndef SAMPLE_PLAYER_H
+#define SAMPLE_PLAYER_H
+
+#include "action_generator.h"
+#include "field_evaluator.h"
+#include "communication.h"
 
 #include <rcsc/player/player_agent.h>
+#include <vector>
 
 class SamplePlayer
     : public rcsc::PlayerAgent {
+private:
+
+    Communication::Ptr M_communication;
+
+    FieldEvaluator::ConstPtr M_field_evaluator;
+    ActionGenerator::ConstPtr M_action_generator;
+
 public:
 
     SamplePlayer();
@@ -55,25 +67,34 @@ protected:
     virtual
     void communicationImpl();
 
-    //
-    // hook method for handling server param message
-    //
+    virtual
+    void handleActionStart();
+    virtual
+    void handleActionEnd();
+
     virtual
     void handleServerParam();
     virtual
     void handlePlayerParam();
     virtual
     void handlePlayerType();
+
+    virtual
+    FieldEvaluator::ConstPtr createFieldEvaluator() const;
+
+    virtual
+    ActionGenerator::ConstPtr createActionGenerator() const;
+
 private:
 
-    bool sayBall();
-    bool saySelf();
-    bool sayGoalie();
-    bool sayIntercept();
-    bool sayOffsideLine();
-    bool sayDefenseLine();
+    bool doPreprocess();
+    bool doShoot();
+    bool doForceKick();
+    bool doHeardPassReceive();
 
-    void attentiontoSomeone();
+public:
+    virtual
+    FieldEvaluator::ConstPtr getFieldEvaluator() const;
 };
 
 #endif
