@@ -41,6 +41,8 @@
 #include <rcsc/param/cmd_line_parser.h>
 #include <rcsc/random.h>
 
+using namespace rcsc;
+
 /*-------------------------------------------------------------------*/
 /*!
 
@@ -54,7 +56,7 @@ SampleTrainer::SampleTrainer()
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
+ */
 SampleTrainer::~SampleTrainer()
 {
 
@@ -65,28 +67,24 @@ SampleTrainer::~SampleTrainer()
 
  */
 bool
-SampleTrainer::initImpl( rcsc::CmdLineParser & cmd_parser )
+SampleTrainer::initImpl( CmdLineParser & cmd_parser )
 {
-    bool result = rcsc::TrainerAgent::initImpl( cmd_parser );
+    bool result = TrainerAgent::initImpl( cmd_parser );
 
-    rcsc::ParamMap my_params;
 #if 0
+    ParamMap my_params;
+
     std::string formation_conf;
     my_map.add()
         ( &conf_path, "fconf" )
         ;
-#endif
-    cmd_parser.parse( my_params );
 
-    if ( cmd_parser.count( "help" ) )
-    {
-        my_params.printHelp( std::cout );
-        return false;
-    }
+    cmd_parser.parse( my_params );
+#endif
 
     if ( cmd_parser.failed() )
     {
-        std::cerr << "trainer: ***WARNING*** detected unsupported options: ";
+        std::cerr << "coach: ***WARNING*** detected unsupported options: ";
         cmd_parser.print( std::cerr );
         std::cerr << std::endl;
     }
@@ -100,7 +98,6 @@ SampleTrainer::initImpl( rcsc::CmdLineParser & cmd_parser )
     // Add your code here.
     //////////////////////////////////////////////////////////////////
 
-
     return true;
 }
 
@@ -111,15 +108,20 @@ SampleTrainer::initImpl( rcsc::CmdLineParser & cmd_parser )
 void
 SampleTrainer::actionImpl()
 {
-    //////////////////////////////////////////////////////////////////
-    // This function is a sample trainer action.
-    // At first, remove this.
-    sampleAction();
+    if ( world().teamNameLeft().empty() )
+    {
+        doTeamNames();
+        return;
+    }
 
+    //////////////////////////////////////////////////////////////////
     // Add your code here.
-    //////////////////////////////////////////////////////////////////
-}
 
+    //sampleAction();
+    //recoverForever();
+    //doSubstitute();
+    doKeepaway();
+}
 
 /*-------------------------------------------------------------------*/
 /*!
@@ -133,7 +135,7 @@ SampleTrainer::sampleAction()
     static int s_state = 0;
     static int s_wait_counter = 0;
 
-    static rcsc::Vector2D s_last_player_move_pos;
+    static Vector2D s_last_player_move_pos;
 
     if ( world().existKickablePlayer() )
     {
@@ -150,16 +152,16 @@ SampleTrainer::sampleAction()
         // recover stamina
         doRecover();
         // move ball to center
-        doMoveBall( rcsc::Vector2D( 0.0, 0.0 ),
-                    rcsc::Vector2D( 0.0, 0.0 ) );
+        doMoveBall( Vector2D( 0.0, 0.0 ),
+                    Vector2D( 0.0, 0.0 ) );
         // change playmode to play_on
-        doChangeMode( rcsc::PM_PlayOn );
+        doChangeMode( PM_PlayOn );
         {
             // move player to random point
-            rcsc::UniformReal uni01( 0.0, 1.0 );
-            rcsc::Vector2D move_pos
-                = rcsc::Vector2D::polar2vector( 20.0,
-                                                rcsc::AngleDeg( 360.0 * uni01() ) );
+            UniformReal uni01( 0.0, 1.0 );
+            Vector2D move_pos
+                = Vector2D::polar2vector( 15.0, //20.0,
+                                          AngleDeg( 360.0 * uni01() ) );
             s_last_player_move_pos = move_pos;
 
             doMovePlayer( config().teamName(),
@@ -167,9 +169,16 @@ SampleTrainer::sampleAction()
                           move_pos,
                           move_pos.th() - 180.0 );
         }
+        // change player type
+        {
+            static int type = 0;
+            doChangePlayerType( world().teamNameLeft(), 1, type );
+            type = ( type + 1 ) % PlayerParam::i().playerTypes();
+        }
+
         doSay( "move player" );
         s_state = 2;
-        std::cout << "trainer: actionImpl set ball center" << std::endl;
+        std::cout << "trainer: actionImpl init episode." << std::endl;
         break;
     case 2:
         ++s_wait_counter;
@@ -177,13 +186,16 @@ SampleTrainer::sampleAction()
              && ! world().playersLeft().empty() )
         {
             // add velocity to the ball
-            rcsc::UniformReal uni_spd( 2.0, rcsc::ServerParam::i().ballSpeedMax() );
-            rcsc::UniformReal uni_ang( -50.0, 50.0 );
-            rcsc::Vector2D velocity
-                = rcsc::Vector2D::polar2vector( uni_spd(),
-                                                s_last_player_move_pos.th()
-                                                + uni_ang() );
-            doMoveBall( rcsc::Vector2D( 0.0, 0.0 ),
+            //UniformReal uni_spd( 2.7, 3.0 );
+            //UniformReal uni_spd( 2.5, 3.0 );
+            UniformReal uni_spd( 2.3, 2.7 );
+            //UniformReal uni_ang( -50.0, 50.0 );
+            UniformReal uni_ang( -10.0, 10.0 );
+            Vector2D velocity
+                = Vector2D::polar2vector( uni_spd(),
+                                          s_last_player_move_pos.th()
+                                          + uni_ang() );
+            doMoveBall( Vector2D( 0.0, 0.0 ),
                         velocity );
             s_state = 0;
             s_wait_counter = 0;
@@ -193,3 +205,76 @@ SampleTrainer::sampleAction()
 
     }
 }
+
+/*-------------------------------------------------------------------*/
+/*!
+
+ */
+void
+SampleTrainer::recoverForever()
+{
+    if ( world().playersLeft().empty() )
+    {
+        return;
+    }
+
+    if ( world().time().stopped() == 0
+         && world().time().cycle() % 50 == 0 )
+    {
+        // recover stamina
+        doRecover();
+    }
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+ */
+void
+SampleTrainer::doSubstitute()
+{
+    static bool s_substitute = false;
+    if ( ! s_substitute
+         && world().time().cycle() == 0
+         && world().time().stopped() >= 10 )
+    {
+        std::cerr << "trainer " << world().time() << " team name = "
+                  << world().teamNameLeft()
+                  << std::endl;
+
+        if ( ! world().teamNameLeft().empty() )
+        {
+            UniformSmallInt uni( 0, PlayerParam::i().ptMax() );
+            doChangePlayerType( world().teamNameLeft(),
+                                1,
+                                uni() );
+
+            s_substitute = true;
+        }
+    }
+
+    if ( world().time().stopped() == 0
+         && world().time().cycle() % 100 == 1
+         && ! world().teamNameLeft().empty() )
+    {
+        static int type = 0;
+        doChangePlayerType( world().teamNameLeft(), 1, type );
+        type = ( type + 1 ) % PlayerParam::i().playerTypes();
+    }
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+ */
+void
+SampleTrainer::doKeepaway()
+{
+    if ( world().trainingTime() == world().time() )
+    {
+        std::cerr << "trainer: "
+                  << world().time()
+                  << " keepaway training time." << std::endl;
+    }
+
+}
