@@ -7,7 +7,7 @@
 
  This code is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2, or (at your option)
+ the Free Software Foundation; either version 3, or (at your option)
  any later version.
 
  This code is distributed in the hope that it will be useful,
@@ -33,8 +33,8 @@ class SampleTrainer
     : public rcsc::TrainerAgent {
 private:
 
-
 public:
+
     SampleTrainer();
 
     virtual
@@ -47,16 +47,19 @@ protected:
       But you must call TrainerAgent::doInit() in this method.
     */
     virtual
-    bool doInit( rcsc::CmdLineParser & cmd_parser );
+    bool initImpl( rcsc::CmdLineParser & cmd_parser );
 
     //! main decision
     virtual
-    void doAction();
+    void actionImpl();
 
 
 private:
 
     void sampleAction();
+    void recoverForever();
+    void doSubstitute();
+    void doKeepaway();
 
 };
 
